pub struct JoinContext<'a> {
pub left: &'a RecordBatch,
pub right: &'a RecordBatch,
pub left_row: usize,
pub right_row: usize,
pub left_alias: Option<&'a str>,
pub right_alias: Option<&'a str>,
}Expand description
Join execution context containing the left and right inputs and join condition.
This context is used by join executors to perform various join algorithms (nested loop, hash join, sort-merge join) on the input data streams.
Fields
left: &'a RecordBatchLeft record batch.
right: &'a RecordBatchRight record batch.
left_row: usizeCurrent left row index.
right_row: usizeCurrent right row index.
left_alias: Option<&'a str>Left table alias (if any).
right_alias: Option<&'a str>Right table alias (if any).