pub struct PredicatePushdown;Expand description
Predicate pushdown rule.
Pushes filter predicates down to table scans and joins. This optimization reduces the amount of data processed by applying filters as early as possible in the query execution plan.