JoinContext

Struct JoinContext 

pub struct JoinContext<'a> {
    pub left: &'a RecordBatch,
    pub right: &'a RecordBatch,
    pub left_row: usize,
    pub right_row: usize,
    pub left_alias: Option<&'a str>,
    pub right_alias: Option<&'a str>,
}
Join execution context containing the left and right inputs and join condition.

This context is used by join executors to perform various join algorithms (nested loop, hash join, sort-merge join) on the input data streams.

Fields

left: &'a RecordBatch

Left record batch.

right: &'a RecordBatch

Right record batch.

left_row: usize

Current left row index.

right_row: usize

Current right row index.

left_alias: Option<&'a str>

Left table alias (if any).

right_alias: Option<&'a str>

Right table alias (if any).